@@ -1,7 +1,5 @@
 from judgeval.scorers.api_scorer import (
     APIScorerConfig,
-    ExampleAPIScorerConfig,
-    TraceAPIScorerConfig,
 )
 from judgeval.constants import APIScorerType
 from typing import Dict, Any, Optional
@@ -55,7 +53,7 @@ def fetch_prompt_scorer(
 ):
     client = JudgmentSyncClient(judgment_api_key, organization_id)
     try:
-        scorer_config = client.fetch_scorer({"name": name})["scorer"]
+        scorer_config = client.fetch_scorers({"names": [name]})["scorers"][0]
         scorer_config.pop("created_at")
         scorer_config.pop("updated_at")
         return scorer_config
@@ -284,9 +282,9 @@ class BasePromptScorer(ABC, APIScorerConfig):
         return base
 
 
-class PromptScorer(BasePromptScorer, ExampleAPIScorerConfig):
+class PromptScorer(BasePromptScorer, APIScorerConfig):
     pass
 
 
-class TracePromptScorer(BasePromptScorer, TraceAPIScorerConfig):
+class TracePromptScorer(BasePromptScorer, APIScorerConfig):
     pass
