@@ -43,8 +43,8 @@ from judgeval.env import (
     JUDGMENT_ORG_ID,
 )
 from judgeval.logger import judgeval_logger
-from judgeval.scorers.api_scorer import ExampleAPIScorerConfig, TraceAPIScorerConfig
-from judgeval.scorers.base_scorer import BaseScorer
+from judgeval.scorers.api_scorer import APIScorerConfig
+from judgeval.scorers.example_scorer import ExampleScorer
 from judgeval.tracer.constants import JUDGEVAL_TRACER_INSTRUMENTING_MODULE_NAME
 from judgeval.tracer.managers import (
     sync_span_context,
@@ -328,7 +328,7 @@ class Tracer:
         run_condition = scorer_config.run_condition
         sampling_rate = scorer_config.sampling_rate
 
-        if not isinstance(scorer, (TraceAPIScorerConfig)):
+        if not isinstance(scorer, (APIScorerConfig)):
             judgeval_logger.error(
                 "Scorer must be an instance of TraceAPIScorerConfig, got %s, skipping evaluation."
                 % type(scorer)
@@ -358,7 +358,6 @@ class Tracer:
         eval_run_name = f"async_trace_evaluate_{span_id}"
 
         eval_run = TraceEvaluationRun(
-            organization_id=self.organization_id,
             project_name=self.project_name,
             eval_name=eval_run_name,
             scorers=[scorer],
@@ -862,7 +861,7 @@ class Tracer:
         self,
         /,
         *,
-        scorer: Union[ExampleAPIScorerConfig, BaseScorer],
+        scorer: Union[APIScorerConfig, ExampleScorer],
         example: Example,
         model: str = JUDGMENT_DEFAULT_GPT_MODEL,
         sampling_rate: float = 1.0,
@@ -871,7 +870,7 @@ class Tracer:
             judgeval_logger.info("Evaluation is not enabled, skipping evaluation")
             return
 
-        if not isinstance(scorer, (ExampleAPIScorerConfig, BaseScorer)):
+        if not isinstance(scorer, (APIScorerConfig, ExampleScorer)):
             judgeval_logger.error(
                 "Scorer must be an instance of ExampleAPIScorerConfig or BaseScorer, got %s, skipping evaluation."
                 % type(scorer)
@@ -902,13 +901,12 @@ class Tracer:
         span_context = self.get_current_span().get_span_context()
         trace_id = format(span_context.trace_id, "032x")
         span_id = format(span_context.span_id, "016x")
-        hosted_scoring = isinstance(scorer, ExampleAPIScorerConfig) or (
-            isinstance(scorer, BaseScorer) and scorer.server_hosted
+        hosted_scoring = isinstance(scorer, APIScorerConfig) or (
+            isinstance(scorer, ExampleScorer) and scorer.server_hosted
         )
         eval_run_name = f"async_evaluate_{span_id}"  # note this name doesnt matter because we don't save the experiment only the example and scorer_data
         if hosted_scoring:
             eval_run = ExampleEvaluationRun(
-                organization_id=self.organization_id,
                 project_name=self.project_name,
                 eval_name=eval_run_name,
                 examples=[example],
@@ -923,7 +921,6 @@ class Tracer:
         else:
             # Handle custom scorers using local evaluation queue
             eval_run = ExampleEvaluationRun(
-                organization_id=self.organization_id,
                 project_name=self.project_name,
                 eval_name=eval_run_name,
                 examples=[example],
