@@ -2,7 +2,7 @@ from typing import Any
 from opentelemetry.trace import Span
 from pydantic import BaseModel
 from typing import Callable, Optional
-from judgeval.scorers.api_scorer import TraceAPIScorerConfig
+from judgeval.scorers.api_scorer import APIScorerConfig
 from judgeval.env import JUDGMENT_DEFAULT_GPT_MODEL
 
 
@@ -14,7 +14,7 @@ def set_span_attribute(span: Span, name: str, value: Any):
 
 
 class TraceScorerConfig(BaseModel):
-    scorer: TraceAPIScorerConfig
+    scorer: APIScorerConfig
     model: str = JUDGMENT_DEFAULT_GPT_MODEL
     sampling_rate: float = 1.0
     run_condition: Optional[Callable[..., bool]] = None
